Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(9040)

Unified Diff: chrome/browser/ui/views/bookmarks/bookmark_bar_view.h

Issue 769153007: Managed bookmarks for supervised users (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: string change Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/bookmarks/bookmark_bar_view.h
diff --git a/chrome/browser/ui/views/bookmarks/bookmark_bar_view.h b/chrome/browser/ui/views/bookmarks/bookmark_bar_view.h
index 9eb766d87d315ccbaaafff1dce398e9823761cb7..c034286751c744416cd658ed1c7c89de3a2f30eb 100644
--- a/chrome/browser/ui/views/bookmarks/bookmark_bar_view.h
+++ b/chrome/browser/ui/views/bookmarks/bookmark_bar_view.h
@@ -304,6 +304,9 @@ class BookmarkBarView : public views::AccessiblePaneView,
// Creates the button showing the "Managed Bookmarks" folder.
views::MenuButton* CreateManagedBookmarksButton();
+ // Creates the button showing the supervised bookmarks items.
+ views::MenuButton* CreateSupervisedBookmarksButton();
+
// Creates the button used when not all bookmark buttons fit.
views::MenuButton* CreateOverflowButton();
@@ -368,8 +371,9 @@ class BookmarkBarView : public views::AccessiblePaneView,
// Updates the colors for all the child objects in the bookmarks bar.
void UpdateColors();
// Updates the visibility of |other_bookmarks_button_| and
// |managed_bookmarks_button_|. Also shows or hides the separator if required.
// Returns true if something changed and a LayoutAndPaint() is needed.
bool UpdateOtherAndManagedButtonsVisibility();
@@ -418,6 +422,9 @@ class BookmarkBarView : public views::AccessiblePaneView,
// Shows the managed bookmarks entries.
views::MenuButton* managed_bookmarks_button_;
+ // Shows the supervised bookmarks entries.
+ views::MenuButton* supervised_bookmarks_button_;
+
// Shows the Apps page shortcut.
views::LabelButton* apps_page_shortcut_;
@@ -368,8 +371,9 @@ class BookmarkBarView : public views::AccessiblePaneView,
// Updates the colors for all the child objects in the bookmarks bar.
void UpdateColors();
- // Updates the visibility of |other_bookmarks_button_| and
- // |managed_bookmarks_button_|. Also shows or hides the separator if required.
+ // Updates the visibility of |other_bookmarks_button_|,
+ // |managed_bookmarks_button_|, and |supervised_bookmarks_button_|. Also
+ // shows or hides the separator if required.
// Returns true if something changed and a LayoutAndPaint() is needed.
bool UpdateOtherAndManagedButtonsVisibility();

Powered by Google App Engine
This is Rietveld 408576698